var folderClosed = new Image(48,48);
folderClosed.src='/style/Crystal/48/html-menu-treeview/folder.png';
var plusNode = new Image(48,48);
plusNode.src='/style/Crystal/48/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(48,48);
lastPlusNode.src='/style/Crystal/48/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(48,48);
clasicPlusNode.src='/style/Crystal/48/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(48,48);
clasicLastPlusNode.src='/style/Crystal/48/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folder_man.png';
var folderGray = new Image(48,48);
folderGray.src='/style/Crystal/48/html-menu-treeview/folder_grey.png';
var folderGreen = new Image(48,48);
folderGreen.src='/style/Crystal/48/html-menu-treeview/folder_green.png';
var folderViolet = new Image(48,48);
folderViolet.src='/style/Crystal/48/html-menu-treeview/folder_violet.png';
var folderYellowClosed = new Image(48,48);
folderYellowClosed.src='/style/Crystal/48/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(48,48);
folderOrangeClosed.src='/style/Crystal/48/html-menu-treeview/folder_orange.png';
var folderManClosed = new Image(48,48);
folderManClosed.src='/style/Crystal/48/html-menu-treeview/folder_man.png';
var folderHtmlClosed = new Image(48,48);
folderHtmlClosed.src='/style/Crystal/48/html-menu-treeview/folder_html.png';
var folderFavoriteClosed = new Image(48,48);
folderFavoriteClosed.src='/style/Crystal/48/html-menu-treeview/folder_favorite.png';
var folderTextClosed = new Image(48,48);
folderTextClosed.src='/style/Crystal/48/html-menu-treeview/folder_txt.png';
var folderLockedClosed = new Image(48,48);
folderLockedClosed.src='/style/Crystal/48/html-menu-treeview/folder_locked.png';
var folderCrystalClosed = new Image(48,48);
folderCrystalClosed.src='/style/Crystal/48/html-menu-treeview/folder_crystal.png';
var folderVideoClosed = new Image(48,48);
folderVideoClosed.src='/style/Crystal/48/html-menu-treeview/folder_video.png';
var folderPrintClosed = new Image(48,48);
folderPrintClosed.src='/style/Crystal/48/html-menu-treeview/folder_print.png';
var folderImageClosed = new Image(48,48);
folderImageClosed.src='/style/Crystal/48/html-menu-treeview/folder_image.png';
var folderSoundClosed = new Image(48,48);
folderSoundClosed.src='/style/Crystal/48/html-menu-treeview/folder_sound.png';
var folderImportantClosed = new Image(48,48);
folderImportantClosed.src='/style/Crystal/48/html-menu-treeview/folder_important.png';
var folderTarClosed = new Image(48,48);
folderTarClosed.src='/style/Crystal/48/html-menu-treeview/folder_tar.png';
