var folderClosed = new Image(22,22);
folderClosed.src='/style/Crystal/22/html-menu-treeview/folder.png';
var plusNode = new Image(22,22);
plusNode.src='/style/Crystal/22/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(22,22);
lastPlusNode.src='/style/Crystal/22/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(22,22);
clasicPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(22,22);
clasicLastPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif';
var folderGray = new Image(22,22);
folderGray.src='/style/Crystal/22/html-menu-treeview/folder_grey.png';
var folderGreen = new Image(22,22);
folderGreen.src='/style/Crystal/22/html-menu-treeview/folder_green.png';
var folderViolet = new Image(22,22);
folderViolet.src='/style/Crystal/22/html-menu-treeview/folder_violet.png';
var folderYellowClosed = new Image(22,22);
folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folder_yellow.png';
var folderOrangeClosed = new Image(22,22);
folderOrangeClosed.src='/style/Crystal/22/html-menu-treeview/folder_orange.png';
var folderPrintClosed = new Image(22,22);
folderPrintClosed.src='/style/Crystal/22/html-menu-treeview/folder_print.png';
